pub struct Engine { /* private fields */ }Expand description
Canonical RBAC + ABAC engine with deny-override and default-deny semantics.
Implementations
Sourceimpl Engine
impl Engine
Sourcepub fn new(roles: Vec<Role>, policies: Vec<Policy>) -> AppResult<Self>
pub fn new(roles: Vec<Role>, policies: Vec<Policy>) -> AppResult<Self>
Construct an engine from roles and policies.
Evaluate a request.
Deny policies are evaluated before role grants and allow policies.
Object-level constraints that should limit a role should be attached to the role Permission;
constraints that must override any broad grant should be modeled as deny policies.